@@ -15,7 +15,7 @@ class MakeTestRequest(unittest.TestCase):
     def test(self):
         key  = uuid4().hex
         meth = b"<method />"
-        out  = make.request(key, meth)
+        out  = make.request(key.encode("utf8"), meth)
         xml  = _xml(out)
 
         self.assertEqual(xml.tag,        "request")
@@ -45,21 +45,6 @@ class MakeTestAdd(unittest.TestCase):
         self.assertEqual(xml.get("type"),    "19")
         self.assertEqual(xml.get("comment"), "abused vpn")
 
-    def test_many(self):
-        out = make.add([IP, IP], 19, "abused vpn", 1337)
-        xml = _xml(make.request("", out))
-
-        self.assertEqual(xml[0].tag,            "add")
-        self.assertEqual(xml[0].get("ip"),      IP)
-        self.assertEqual(xml[0].get("port"),    "1337")
-        self.assertEqual(xml[0].get("type"),    "19")
-        self.assertEqual(xml[0].get("comment"), "abused vpn")
-
-        self.assertEqual(xml[0].get("ip"),      xml[1].get("ip"))
-        self.assertEqual(xml[0].get("port"),    xml[1].get("port"))
-        self.assertEqual(xml[0].get("type"),    xml[1].get("type"))
-        self.assertEqual(xml[0].get("comment"), xml[1].get("comment"))
-
 class MakeTestLookup(unittest.TestCase):
     def test_ip_with_type(self):
         out = make.lookup(IP, 19)
@@ -98,3 +83,26 @@ class MakeTestRemove(unittest.TestCase):
 
         self.assertEqual(xml.tag,       "remove")
         self.assertEqual(xml.get("id"), str(ID))
+
+class MakeTestBatch(unittest.TestCase):
+    def test(self):
+        bat  = make.Batch()
+
+        bat.add(IP, 19, "abused vpn", 1337)
+        ref  = make.add(IP, 19, "abused vpn", 1337)
+
+        bat.remove(ID)
+        ref += make.remove(ID)
+
+        acts = [("add", IP), ("remove", str(ID))]
+
+        self.assertEqual(bat.data,    ref)
+        self.assertEqual(bat.actions, acts)
+
+    def test_type(self):
+        bat = make.TypeBatch(19)
+        bat.add(IP, "abused vpn", 1337)
+        ref = make.add(IP, 19, "abused vpn", 1337)
+
+        self.assertEqual(bat.data,    ref)
+        self.assertEqual(bat.actions, [("add", IP)])
